@@ -1,4 +1,3 @@
-/* $Id$ */
 /*-
  * Copyright (c) 2004-2006  os-cillation e.K.
  * Copyright (c) 2002,2004  Anders Carlsson <andersca@gnu.org>
@@ -234,7 +233,7 @@ void                  exo_icon_view_icon_to_widget_coords     (const ExoIconView
                                                                gint                      ix,
                                                                gint                      iy,
                                                                gint                     *wx,
-                                                             gint                     *wy);
+                                                               gint                     *wy);
 
 GtkTreePath          *exo_icon_view_get_path_at_pos           (const ExoIconView        *icon_view,
                                                                gint                      x,
@@ -264,6 +263,11 @@ void                  exo_icon_view_unselect_all              (ExoIconView
 void                  exo_icon_view_item_activated            (ExoIconView              *icon_view,
                                                                GtkTreePath              *path);
 
+gint                  exo_icon_view_get_item_column           (ExoIconView              *icon_view,
+                                                               GtkTreePath              *path);
+gint                  exo_icon_view_get_item_row              (ExoIconView              *icon_view,
+                                                               GtkTreePath              *path);
+
 gboolean              exo_icon_view_get_cursor                (const ExoIconView        *icon_view,
                                                                GtkTreePath             **path,
                                                                GtkCellRenderer         **cell);
